@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.20.1-Odense"
-#define _QGIS_VERSION "3.20.1-Odense"
+#define VERSION "3.24.1-Tisler"
+#define _QGIS_VERSION "3.24.1-Tisler"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3201
+//#define VERSION_INT 3241
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 32001
-#define _QGIS_VERSION_INT 32001
-#define ABISYM(x) x ## 32001
+#define VERSION_INT 32401
+#define _QGIS_VERSION_INT 32401
+#define ABISYM(x) x ## 32401
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Odense"
+#define RELEASE_NAME "Tisler"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,12 +31,12 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.20.1"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.24.1"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
 #if !defined(QSCINTILLA_VERSION_STR)
-#define QSCINTILLA_VERSION_STR "2.13.0"
+#define QSCINTILLA_VERSION_STR "2.13.2"
 #endif
 
 #if defined( __APPLE__ )
@@ -46,10 +46,14 @@
 
 #define QT_PLUGINS_DIR "/usr/lib/qt/plugins"
 
-#define PYTHON_VERSION "3.9.6"
+#define PYTHON_VERSION "3.10.4"
 #define PYTHON_VERSION_MAJOR "3"
-#define PYTHON_VERSION_MINOR "9"
-#define PYTHON_VERSION_PATCH "6"
+#define PYTHON_VERSION_MINOR "10"
+#define PYTHON_VERSION_PATCH "4"
+
+#define PROJ_VERSION_MAJOR 8
+#define PROJ_VERSION_MINOR 2
+#define PROJ_VERSION_PATCH 0
 
 /* #undef USING_NMAKE */
 
@@ -69,6 +73,8 @@
 
 #define HAVE_SERVER_PYTHON_PLUGINS
 
+#define HAVE_OAUTH2_PLUGIN
+
 #define HAVE_OPENCL
 #define OPENCL_USE_NEW_HEADER
 
@@ -92,15 +98,21 @@
 
 #define HAVE_EPT
 
-#define HAVE_PDAL
-#define PDAL_VERSION "2.3.0"
+#define HAVE_PDAL_QGIS
+#define PDAL_VERSION "2.4.0"
 #define PDAL_VERSION_MAJOR_INT 2
-#define PDAL_VERSION_MINOR_INT 3
+#define PDAL_VERSION_MINOR_INT 4
 #define PDAL_VERSION_MAJOR "2"
-#define PDAL_VERSION_MINOR "3"
+#define PDAL_VERSION_MINOR "4"
 #define PDAL_VERSION_MICRO "0"
 
 #define ENABLE_TESTS
 
+/* #undef HAS_KDE_QT5_PDF_TRANSFORM_FIX */
+/* #undef HAS_KDE_QT5_SMALL_CAPS_FIX */
+/* #undef HAS_KDE_QT5_FONT_STRETCH_FIX */
+
+#define HAVE_CRASH_HANDLER
+
 #endif
 
